import pandas as pd
import pytest

from toarstats.metrics.constants import STATISTICS_LIST
from toarstats.metrics.stats_utils import (
    get_growing_season, get_seasons, harmonize_time, kth_highest, prepare_data,
    STATS_LIST
)


def test_statistics_list_is_complete():
    assert sorted(STATISTICS_LIST) == sorted(STATS_LIST)


def test_get_growing_season():
    with pytest.raises(
            KeyError,
            match="wheat-cool_temperate_le30-SH not included in SEASON_DICT"
    ):
        growing_season = get_growing_season("wheat", "cool temperate", -15)


def test_get_seasons():
    seasons = get_seasons(
        None, ["mean", "median"], None, ["DJF", "MAM"], None, True, False
    )
    assert seasons == [["DJF", "MAM"], ["DJF", "MAM"]]


def test_harmonize_time():
    record_list = harmonize_time([{"ser": pd.Series()}], "monthly")
    for record in record_list:
        pd.testing.assert_index_equal(
            record["ser"].index, pd.DatetimeIndex([])
        )


def test_kth_highest():
    ser = kth_highest(
        pd.Series(index=pd.DatetimeIndex([])), None, "annual", 26, 0.75
    )
    pd.testing.assert_series_equal(
        ser, pd.Series(index=pd.DatetimeIndex([], ser.index.freq), dtype=float)
    )


def test_prepare_data():
    record = prepare_data(
        pd.Series(index=pd.DatetimeIndex([])),
        pd.Series(index=pd.DatetimeIndex(["2000"])),
        "seasonal", ["DJF"], "mean"
    )
    assert record[0]["ser"].index == pd.DatetimeIndex(["2000"])
